package blackbox;

import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;
import java.util.Scanner;

import javax.swing.filechooser.FileFilter;


/**
 * File filter for XML files.
 *
 * @author Robbie McElrath
 */
class XMLFilter extends FileFilter {
  /**
   * Whether the given file is accepted by this filter.
   *
   * @param f The file to check
   * @return true if the File is valid
   */
  @Override
  public boolean accept(File f) {
    if (f.isDirectory()) {
      return true;
    }
    return f.getName().toLowerCase().endsWith(".xml");
  }

  /**
   * The description of this filter.
   *
   * @return The filter's description
   */
  @Override
  public String getDescription() {
    return "XML Files";
  }
}


/**
 * Filters BlackBox2 Generated Gauges. These are XML gauges with the proper prefix. The prefix is
 * used to ensure that a) the file is the proper format for reading it back into BlackBox, and b) to
 * ensure that the user can only overwrite a BlackBox gauge during a save (as opposed to the one
 * they were working on, which has happened).
 *
 * @author Robbie McElrath
 */
class BBXMLFilter extends XMLFilter {
  /**
   * Whether the given file is accepted by this filter.
   *
   * @param f The file to check
   * @return true if the File is valid
   */
  @Override
  public boolean accept(File f) {
    if (f.isDirectory() || !f.exists()) {
      return true;
    }
    if (!f.getName().toLowerCase().endsWith(".xml")) {
      return false;
    }
    try (Scanner scanner = new Scanner(f)) {
      if (scanner.hasNextLine()) {
        String line = scanner.nextLine();
        scanner.close();
        return line.equals(BlackBox3.GAUGE_HEADER);
      }
      return false;
    } catch (IOException e) {
      return false;
    }
  }

  /**
   * The description of this filter.
   *
   * @return The filter's description
   */
  @Override
  public String getDescription() {
    return "BlackBox2 XML Files";
  }
}


/**
 * Filters "template" files.
 *
 * @author Robbie McElrath
 */
class TemplateFilter implements FilenameFilter {
  /**
   * Whether the given file is accepted by this filter.
   *
   * @param f The file to check
   * @return true if the File is valid
   */
  @Override
  public boolean accept(File dir, String name) {
    return name.endsWith(".template");
  }
}
