package blackbox;

import java.util.Enumeration;

import javax.swing.AbstractButton;
import javax.swing.Action;
import javax.swing.ButtonGroup;
import javax.swing.Icon;
import javax.swing.JCheckBoxMenuItem;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JRadioButtonMenuItem;


public class MenuBar {
  private JMenuBar menubar;

  private MenuBar() {
    menubar = new JMenuBar();
  }

  public static MenuBar createMenuBar() {
    return new MenuBar();
  }

  public JMenuBar getJMenuBar() {
    return menubar;
  }

  public MenuBar addMenu(Menu menu) {
    menubar.add(menu.getJMenu());
    return this;
  }

  public static Menu createMenu(String title) {
    return new Menu(title);
  }

  public static Menu createMenu(String title, Icon icon) {
    Menu mn = new Menu(title);
    mn.getJMenu().setIcon(icon);
    return mn;
  }

  public static RadioGroup createRadioGroup() {
    return new RadioGroup();
  }

  public static class Menu {
    private JMenu menu;

    public Menu(String title) {
      menu = new JMenu(title);
    }

    public JMenu getJMenu() {
      return menu;
    }

    public Menu addItem(Action actn) {
      menu.add(new JMenuItem(actn));
      return this;
    }

    public Menu addItem(JMenuItem item) {
      menu.add(item);
      return this;
    }

    public Menu addCheckItem(Action actn) {
      menu.add(new JCheckBoxMenuItem(actn));
      return this;
    }

    public Menu addCheckItem(JCheckBoxMenuItem item) {
      menu.add(item);
      return this;
    }

    public Menu addRadioGroup(RadioGroup group) {
      Enumeration<AbstractButton> buttons = group.getButtonGroup().getElements();
      while (buttons.hasMoreElements()) {
        menu.add(buttons.nextElement());
      }
      return this;
    }

    public Menu addSeperator() {
      menu.addSeparator();
      return this;
    }

    public Menu addMenu(Menu submenu) {
      menu.add(submenu.getJMenu());
      return this;
    }
  }

  public static class RadioGroup {
    private ButtonGroup group;

    public RadioGroup() {
      group = new ButtonGroup();
    }

    public ButtonGroup getButtonGroup() {
      return group;
    }

    public RadioGroup addRadioItem(Action actn) {
      group.add(new JRadioButtonMenuItem(actn));
      return this;
    }

    public RadioGroup addRadioItem(JRadioButtonMenuItem item) {
      group.add(item);
      return this;
    }
  }
}
